#!/bin/bash
#
# Copyright (c) 2013, Novell, Inc.  All rights reserved.
# USE AND REDISTRIBUTION OF THIS WORK IS SUBJECT TO THE DEVELOPER LICENSE
# AGREEMENT OR OTHER AGREEMENT THROUGH WHICH NOVELL, INC. MAKES THE WORK
# AVAILABLE. THIS WORK MAY NOT BE ADAPTED WITHOUT  NOVELL'S PRIOR WRITTEN
# CONSENT.
#
# NOVELL PROVIDES THE WORK "AS IS," WITHOUT ANY EXPRESS OR IMPLIED WARRANTY,
# INCLUDING WITHOUT THE IMPLIED WARRANTIES OF MERCHANTABILITY,FITNESS FOR
# A PARTICULAR PURPOSE, AND NON-INFRINGEMENT.  NOVELL, THE AUTHORS OF THE
# WORK, AND THE OWNERS OF COPYRIGHT IN THE WORK ARE NOT LIABLE FOR ANY
# CLAIM, DAMAGES, OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
# TORT, OR OTHERWISE, ARISING FROM, OUT OF, OR IN CONNECTION WITH THE WORK
# OR THE USE OR OTHER DEALINGS IN THE WORK.
#
# All rights reserved.
#
#

LDAP_MOD_BIN="env LDAPTLS_CACERT=/etc/opt/novell/certs/SSCert.pem /usr/bin/ldapmodify"
UPDATE_LDIF_FILE="/tmp/modcifsshares.ldif"
LOG_FILE="/var/opt/novell/log/proxymgmt/pxymgmt.log"

#Before running this script, admin password should be exported using OES_DATA environment variable

#Check for root access
user_id=`id -u`
if test $user_id -ne 0
then
	echo "cifs_update_ncp_attribs.sh: Only root user can run this script" >> $LOG_FILE
	echo "cifs_update_ncp_attribs.sh: Only root user can run this script"
	exit 1
fi

#Help of the script
Usage()
{
	echo ""
	echo "Usage: cifs_update_export_shares.sh [options]"
	echo "          -h                      Prints this summary"
	echo "          -d                      LDAP Admin FDN"
	echo "          -D                      NCP Server DN in LDAP format"
	echo "          -i                      LDAP Server IP address"
	echo "          -p                      LDAP Port"
	echo "          -s                      SSL or Not(1 or 0)"
	echo "          -u                      NCP Server Update option. 1,2"
	echo "					1 - Add nfapCIFSShareVolsByDefault attribute to NCP Server with value TRUE"
	echo "					2 - Update nfapCIFSShareVolsByDefault attribute of NCP Server with value TRUE"
	echo ""
	exit 1;
}

#Read the command line arguments and store them
while getopts d:D:i:p:s:u:h o
do
        case "$o" in
			d)LDAP_ADM="$OPTARG";;
			i)LDAP_IP="$OPTARG";;
			p)LDAP_PORT="$OPTARG";;
			D)NCPSERVERDN="$OPTARG";;
			s)SSLORNOT="$OPTARG";;
			u)UPDATE_OPTION="$OPTARG";;
			h)Usage;;
			[?]) Usage;;
        esac
done

if test "$LDAP_ADM" = "" || test "$LDAP_IP" = "" || test "$LDAP_PORT" = "" || test "$NCPSERVERDN" = "" || test "$SSLORNOT" = "" || test "$UPDATE_OPTION" = ""
then
	Usage
fi


if [ -n "$OES_ADMIN_DATA" ]; then
	OES_DATA="$OES_ADMIN_DATA"
fi


#Create LDIF file to add or update nfapCIFSShareVolsByDefault attribute
echo "dn:$NCPSERVERDN" > $UPDATE_LDIF_FILE
echo "changetype:modify" >> $UPDATE_LDIF_FILE
if [ $UPDATE_OPTION = 1 ]
then
	echo "add:nfapCIFSShareVolsByDefault" >> $UPDATE_LDIF_FILE
elif [ $UPDATE_OPTION = 2 ]
then
	echo "replace:nfapCIFSShareVolsByDefault" >> $UPDATE_LDIF_FILE
else
	echo "Invalid CIFS option to update NCP Server: $NCPSERVERDN" >>  $LOG_FILE
	echo "Invalid CIFS option to update NCP Server: $NCPSERVERDN" 
	rm $UPDATE_LDIF_FILE
	exit 1
fi
echo "nfapCIFSShareVolsByDefault:true" >> $UPDATE_LDIF_FILE

#Update NCP Server object
if [ $SSLORNOT != 0 ]
then
	   var=`$LDAP_MOD_BIN -f $UPDATE_LDIF_FILE -H ldaps://"$LDAP_IP":$LDAP_PORT -D "$LDAP_ADM"  -w "$OES_DATA"` >> $LOG_FILE 2>&1
else
	   var=`$LDAP_MOD_BIN -f $UPDATE_LDIF_FILE -H ldap://"$LDAP_IP":$LDAP_PORT -D "$LDAP_ADM"  -w "$OES_DATA"` >> $LOG_FILE 2>&1
fi

#Log the success or error message
UPDATE_RESULT=$?
if [ $UPDATE_RESULT != 0 ]
then
	if  [ $UPDATE_OPTION = 1 ] && [ $UPDATE_RESULT = 20 ]
        then
                echo "NCP Server $NCPSERVERDN already has the attribute nfapCIFSShareVolsByDefault" >> LOG_FILE
                echo "NCP Server $NCPSERVERDN already has the attribute nfapCIFSShareVolsByDefault"
                $UPDATE_RESULT=0
        else
		echo "Error while updating NCP Server: $NCPSERVERDN for nfapCIFSShareVolsByDefault : $UPDATE_RESULT" >> $LOG_FILE
		echo "Error while updating NCP Server: $NCPSERVERDN for nfapCIFSShareVolsByDefault : $UPDATE_RESULT"
	fi
else
	echo "Successfully updated NCP Server: $NCPSERVERDN for nfapCIFSShareVolsByDefault " >> $LOG_FILE
	echo "Successfully updated NCP Server: $NCPSERVERDN for nfapCIFSShareVolsByDefault "
fi

#Remove LDIF file
rm $UPDATE_LDIF_FILE 

#Unset admin password
unset OES_DATA

exit $UPDATE_RESULT

